@@ -1,6 +1,5 @@
-import sysconfig
-import time
 
+import time
 from manafa.services.batteryStatsService import BatteryStatsService
 from manafa.services.service import *
 from manafa.services.perfettoService import PerfettoService
@@ -12,10 +11,10 @@ from manafa.utils.Utils import execute_shell_command, mega_find, get_resources_d
 
 MANAFA_RESOURCES_DIR = get_resources_dir()
 
-DEFAULT_PROFILE= MANAFA_RESOURCES_DIR + "/profiles/power_profile.xml"
-DEFAULT_TIMEZONE="GMT"
+DEFAULT_PROFILE = MANAFA_RESOURCES_DIR + "/profiles/power_profile.xml"
+DEFAULT_TIMEZONE = "GMT"
 
-def getLastBootTime(bts_file=None):
+def get_last_boot_time(bts_file=None):
 	res, out, err = execute_shell_command("adb shell cat /proc/stat | grep btime | awk '{print $2}'") #executeShCommand("adb shell cat /proc/stat | grep btime | awk '{print $2}'")
 	if res != 0 or len(out) == 0:
 		log("no device connected. Assuming Boot time of battery stats file", LogSeverity.ERROR)
@@ -54,7 +53,7 @@ class EManafa(Service):
 		pass
 
 	def init(self):
-		self.boot_time = getLastBootTime()
+		self.boot_time = get_last_boot_time()
 		self.batterystats.init(boot_time=self.boot_time)
 		self.perfetto.init(boot_time=self.boot_time)
 		
@@ -75,7 +74,7 @@ class EManafa(Service):
 		if bts_file == "" or pf_file == "":
 			log("Empty result files", LogSeverity.FATAL)
 			raise Exception()
-		self.b_time = getLastBootTime(bts_file)
+		self.b_time = get_last_boot_time(bts_file)
 		self.bat_events = BatteryStatsParser(self.power_profile, timezone=self.timezone)
 		self.bat_events.parseFile(bts_file)
 		self.perf_events = PerfettoCPUfreqParser(self.power_profile, self.b_time, timezone=self.timezone)
