@@ -9,6 +9,9 @@ def get_resources_dir(packname="manafa", default_res_dir="resources"):
         return  packname + "/" + default_res_dir
     return sysconfig.get_path("purelib") + "/" + packname + "/" + default_res_dir
 
+def get_pack_dir(packname="manafa"):
+    return sysconfig.get_path("purelib") + "/" + packname
+
 
 def get_results_dir(packname="manafa", default_results_dir="results"):
     if DEV:
